.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    lun 03 mar 2014 12:44:39 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

=====================================
 :mod:`sol.models.rating` -- Ratings
=====================================

.. automodule:: sol.models.rating

.. autoclass:: Rating
   :members:
